"use strict";
// noinspection JSUnusedGlobalSymbols
Object.defineProperty(exports, "__esModule", { value: true });
exports.Estimate = void 0;
const af_echo_ts_1 = require("af-echo-ts");
const af_color_1 = require("af-color");
const { formatMilliseconds } = require('af-fns');
class Estimate {
    constructor(total) {
        this.total = total || 0;
        this.startTime = +new Date();
        this.startCircleTime = +new Date();
        this.echo = af_echo_ts_1.echo;
    }
    startProgress(total, roll = 0, msgAdd = '', levelName = 'info') {
        this.total = total;
        this.startCircleTime = +new Date();
        const msg = `${af_color_1.rs}Time taken to start processing: ${af_color_1.magenta}${formatMilliseconds(+new Date() - this.startTime)}${msgAdd ? `${af_color_1.rs} / ${msgAdd}` : ''}`;
        if (process.stdin.isTTY && roll) {
            process.stdout.write(`\x1b[${roll}A${msg}\x1b[K\n`);
        }
        else {
            af_echo_ts_1.echo.log(levelName, msg);
        }
    }
    setTotal(total) {
        this.total = total;
    }
    print(processed, options) {
        var _a, _b, _c;
        const defaultOptions = {
            showPercent: true,
            showCount: true,
            showTakenTime: true,
            roll: 0,
            prefix: '',
            msg: '',
        };
        options = Object.assign(defaultOptions, options || {});
        if (!this.total) {
            af_echo_ts_1.echo.echo(`"Estimate": can't calculate time, "total" parameter is not set`);
            return;
        }
        const txtOf = ((_a = options.of) === null || _a === void 0 ? void 0 : _a.text) || '';
        const txtProcessed = ((_b = options.of) === null || _b === void 0 ? void 0 : _b.processed) || processed;
        const txtTotal = ((_c = options.of) === null || _c === void 0 ? void 0 : _c.total) || this.total;
        let processedString = options.showPercent ? `${af_color_1.magenta}${Math.ceil((txtProcessed / txtTotal) * 100)}${af_color_1.rs}%` : '';
        const countString = options.showCount ? `${txtOf}${af_color_1.magenta}${txtProcessed} ${af_color_1.rs}out of ${af_color_1.magenta}${txtTotal}` : '';
        processedString += (processedString ? ' (' : '') + countString + (processedString ? `${af_color_1.rs})` : '');
        let leftString = `${af_color_1.rs}Left: ${af_color_1.magenta}`;
        if (processed) {
            const msLeft = (+new Date() - this.startCircleTime) * ((this.total / processed) - 1);
            leftString += formatMilliseconds(msLeft);
        }
        else {
            leftString = '';
        }
        const processedTime = options.showTakenTime ? `${af_color_1.rs} / 🕒 ${af_color_1.magenta}${this.getTaken()} ${af_color_1.rs}` : '';
        const roll = options.roll || 0;
        const msgAdd = options.msg || '';
        const msg = `${af_color_1.rs}${options.prefix || ''}Processed ${processedString}${af_color_1.rs}. ${leftString}${processedTime}${msgAdd ? `${af_color_1.rs} / ${msgAdd}` : ''} `;
        if (process.stdin.isTTY && roll) {
            process.stdout.write(`\x1b[${roll}A${msg}\x1b[K\n`);
        }
        else {
            af_echo_ts_1.echo.echo(msg);
        }
    }
    getTaken(isReset = false, isShowMilliseconds = false) {
        const taken = formatMilliseconds(+new Date() - this.startTime, isShowMilliseconds);
        if (isReset) {
            this.reset();
        }
        return taken;
    }
    getRest(processed, fromStart) {
        if (processed && this.total) {
            const msLeft = (+new Date() - (fromStart ? this.startTime : this.startCircleTime)) * ((this.total / processed) - 1);
            return formatMilliseconds(msLeft);
        }
        return '';
    }
    taken(roll, msgAdd, options) {
        const msg = `${af_color_1.rs}Time spent: ${af_color_1.magenta}${this.getTaken()}${msgAdd ? `${af_color_1.rs} / ${msgAdd}` : ''}`;
        if (process.stdin.isTTY && roll) {
            process.stdout.write(`\x1b[${roll}A${msg}\x1b[K\n`);
        }
        else {
            af_echo_ts_1.echo.echo(msg, options);
        }
    }
    reset() {
        this.startTime = +new Date();
        this.startCircleTime = +new Date();
    }
}
exports.Estimate = Estimate;
//# sourceMappingURL=index.js.map